@@ -16,12 +16,23 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#ifndef MON_DIEU_ILS_ONT_TUE_KENNY_H__
-#define MON_DIEU_ILS_ONT_TUE_KENNY_H__
+#ifndef __CATEGORIES_H__
+#define __CATEGORIES_H__
 
-#include <gtk/gtk.h>
+#include <config.h>
+#include <gnome.h>
+#include "config_common.h"
 
-int edit_categories( GtkWidget *w);
 
+void _set_category_name(gchar *string, gpointer data);
+void add_the_categorie(GtkWidget *w, FOLDER *racine);
+void edit_the_categorie(GtkWidget *w, FOLDER *racine);
+void del_the_categorie(GtkWidget *w, FOLDER *racine);
+void cat_selected(GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data);
+void cat_unselected(GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data);
+gboolean category_count (GNode * gn, gpointer data);
+GList *make_categories_list(FOLDER * racine);
+void remove_unused_categories (FOLDER * racine);
+void edit_categories (FOLDER *racine);
 
 #endif
