@@ -83,6 +83,8 @@
 #define GNOMEAPPBAR_MAIN	0
 #define GNOMEAPPBAR_SEARCH	1
 
+#define PROGRESS_BAR_TIMEOUT	2000
+
 #define GNOMEAPPBAR_NB		2
 
 #define	MOUNT_RETRY_TIMEOUT	5
@@ -227,6 +229,7 @@ typedef struct
   
   GList *recent_files;
   gint nb_max_recent_files;
+  gint currently_displayed_recent_files;
   
   gchar *date_format;
 
