@@ -131,7 +131,7 @@ get_path_from_node (GNode * gn)
 }
 
 FILE_DATA *
-folder_make_data (char *name, char *information, guint type, gchar *mime,
+folder_make_data (char *name, char *information, guint type, gchar * mime,
 		  guint32 taille, time_t date,
 		  guint32 categorie, guint32 description)
 {
@@ -141,7 +141,7 @@ folder_make_data (char *name, char *information, guint type, gchar *mime,
   data->name = g_string_new (name);
   data->taille = taille;
   data->type = type;
-  data->mime = g_string_new (mime);;
+  data->mime = g_string_new (mime);
   data->date = date;
   data->categorie = categorie;
   data->description = description;
@@ -152,6 +152,13 @@ folder_make_data (char *name, char *information, guint type, gchar *mime,
   else
     data->information = NULL;
 
+#if defined(__DEBUG__)
+  GML_malloc_forget (data);
+  GML_malloc_forget (data->name);
+  GML_malloc_forget (data->mime);
+  if (data->information)
+    GML_malloc_forget (data->information);
+#endif
   return (data);
 
 }
@@ -159,7 +166,7 @@ folder_make_data (char *name, char *information, guint type, gchar *mime,
 /* Add a file to the FOLDER structure */
 GNode *
 folder_add (FOLDER * fd, GNode * parent, char *name,
-	    char *information, guint type, gchar *mime, guint32 taille,
+	    char *information, guint type, gchar * mime, guint32 taille,
 	    time_t date, guint32 categorie, guint32 description)
 {
 
@@ -178,6 +185,9 @@ folder_add (FOLDER * fd, GNode * parent, char *name,
   g_node_insert (parent, -1, gn);
 
 
+#if defined(__DEBUG__)
+  GML_malloc_forget (data);
+#endif
   return (gn);
 }
 
@@ -192,7 +202,8 @@ folder_add_link (FOLDER * fd, GNode * parent,	/* parent that contains the link *
   gn =
     folder_add (fd, parent, linkname, information, IS_LINK, NULL,
 		0, date, categorie, description);
-  folder_add (fd, gn, destname, NULL, 0, NULL, 0, date, categorie, description);
+  folder_add (fd, gn, destname, NULL, 0, NULL, 0, date, categorie,
+	      description);
   return (gn);
 }
 
@@ -204,6 +215,10 @@ change_name (GNode * gn, char *name)
   fd = get_file_data_from_gnode (gn);
   g_string_free (fd->name, TRUE);
   fd->name = g_string_new (name);
+#if defined(__DEBUG__)
+  if (fd->name)
+    GML_malloc_forget (fd->name);
+#endif
 }
 
 void
@@ -230,10 +245,16 @@ change_information (GNode * gn, char *information)
   FILE_DATA *fd;
 
   fd = get_file_data_from_gnode (gn);
+  if (fd->information)
+    g_string_free (fd->information, TRUE);
   if ((information != NULL) && (strlen (information) != 0))
     fd->information = g_string_new (information);
   else
     fd->information = NULL;
+#if defined(__DEBUG__)
+  if (fd->information)
+    GML_malloc_forget (fd->information);
+#endif
 }
 
 void
@@ -321,13 +342,13 @@ get_time (time_t nb_sec, char *pattern)
 	  if (!strftime (mydate, 255, pattern, time))
 	    {
 	      free (mydate);
-	      memcpy(&nb_sec2, &nb_sec, sizeof(time_t));
+	      memcpy (&nb_sec2, &nb_sec, sizeof (time_t));
 	      mydate = g_strdup (ctime (&nb_sec2));
 	    }
 	}
       else
 	{
-	      memcpy(&nb_sec2, &nb_sec, sizeof(time_t));
+	  memcpy (&nb_sec2, &nb_sec, sizeof (time_t));
 	  mydate = g_strdup (ctime (&nb_sec2));
 	}
     }
@@ -375,7 +396,8 @@ get_categorie (FOLDER * racine, guint16 i)
     }
 }
 
-gint category_id (FOLDER * racine, GString * gs)
+gint
+category_id (FOLDER * racine, GString * gs)
 {
   gint i;
   gint id;
@@ -407,7 +429,8 @@ get_description (FOLDER * racine, guint16 i)
     }
 }
 
-gboolean is_unreadable (GNode * gn)
+gboolean
+is_unreadable (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -417,7 +440,8 @@ gboolean is_unreadable (GNode * gn)
   return (FALSE);
 }
 
-gboolean is_file (GNode * gn)
+gboolean
+is_file (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -427,7 +451,8 @@ gboolean is_file (GNode * gn)
   return (FALSE);
 }
 
-gboolean is_dir (GNode * gn)
+gboolean
+is_dir (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -437,7 +462,8 @@ gboolean is_dir (GNode * gn)
   return (FALSE);
 }
 
-gboolean is_link (GNode * gn)
+gboolean
+is_link (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -449,7 +475,8 @@ gboolean is_link (GNode * gn)
 
 
 
-gboolean is_disk (GNode * gn)
+gboolean
+is_disk (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -459,7 +486,8 @@ gboolean is_disk (GNode * gn)
   return (FALSE);
 }
 
-gboolean is_vfs (GNode * gn)
+gboolean
+is_vfs (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -469,7 +497,8 @@ gboolean is_vfs (GNode * gn)
   return (FALSE);
 }
 
-gboolean is_vfs_extended (GNode * gn)
+gboolean
+is_vfs_extended (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -479,7 +508,8 @@ gboolean is_vfs_extended (GNode * gn)
   return (FALSE);
 }
 
-gboolean is_vfs_any (GNode * gn)
+gboolean
+is_vfs_any (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -489,7 +519,8 @@ gboolean is_vfs_any (GNode * gn)
   return (FALSE);
 }
 
-gboolean is_in_vfs_any (GNode * gn)
+gboolean
+is_in_vfs_any (GNode * gn)
 {
   FILE_DATA *fd;
 
@@ -531,7 +562,8 @@ folder_search_name_in_array (GNode * gn, gchar * name)
 }
 
 
-gboolean _gnode_clear_data (GNode * gn, gpointer data)
+gboolean
+_gnode_clear_data (GNode * gn, gpointer data)
 {
   FOLDER *f = data;
   FILE_DATA *fd;
@@ -554,8 +586,7 @@ gboolean _gnode_clear_data (GNode * gn, gpointer data)
   return (FALSE);
 }
 
-gboolean
-_gnode_clear_ctree_data (GNode * gn, gpointer data)
+gboolean _gnode_clear_ctree_data (GNode * gn, gpointer data)
 {
   FOLDER *racine = data;
   FILE_DATA *fd;
@@ -680,7 +711,8 @@ make_disk_list (FOLDER * racine)
   return (disk_list.list);
 }
 
-gint _cmp_intptrs (gconstpointer a, gconstpointer b)
+gint
+_cmp_intptrs (gconstpointer a, gconstpointer b)
 {
   if (GPOINTER_TO_UINT (a) < GPOINTER_TO_UINT (b))
     return (-1);
@@ -689,7 +721,8 @@ gint _cmp_intptrs (gconstpointer a, gconstpointer b)
   return (0);
 }
 
-gboolean _test_description (GNode * gn, gpointer data)
+gboolean
+_test_description (GNode * gn, gpointer data)
 {
   FILE_DATA *fd;
   guint u = 0;
@@ -706,8 +739,8 @@ gboolean _test_description (GNode * gn, gpointer data)
 	{
 	  g_ptr_array_add (new_descriptions,
 			   (gp =
-			    g_ptr_array_index (my_config->
-					       racine->descriptions, u - 1)));
+			    g_ptr_array_index (my_config->racine->
+					       descriptions, u - 1)));
 	  g_assert (gp != NULL);
 	  g_ptr_array_index (my_config->racine->descriptions, u - 1) = NULL;
 	  g_tree_insert ((GTree *) data, GUINT_TO_POINTER (u),
@@ -717,8 +750,7 @@ gboolean _test_description (GNode * gn, gpointer data)
   return (FALSE);
 }
 
-gboolean
-_adapt_description (GNode * gn, gpointer data)
+gboolean _adapt_description (GNode * gn, gpointer data)
 {
   FILE_DATA *fd;
   guint u = 0, nu;
@@ -798,6 +830,11 @@ init_folder ()
 
   fd->node = racine->tree;
 
+#if defined(__DEBUG__)
+  GML_malloc_forget (racine);
+  GML_malloc_forget (fd);
+  GML_malloc_forget (racine->catalog_filename);
+#endif
   return (racine);
 }
 
@@ -839,8 +876,7 @@ clear_folder (FOLDER * racine)
 
 }
 
-gboolean
-_scan_folders_for_stats (GNode * gn, gpointer data)
+gboolean _scan_folders_for_stats (GNode * gn, gpointer data)
 {
   guint32 *stats = data;
   FILE_DATA *fd;
@@ -871,8 +907,8 @@ _scan_folders_for_stats (GNode * gn, gpointer data)
 }
 
 void
-folder_statistics (FOLDER * racine, GNode *gn, guint32 * nb_desc, guint32 * nb_cat,
-		   guint32 * nb_disks, guint32 * nb_dirs,
+folder_statistics (FOLDER * racine, GNode * gn, guint32 * nb_desc,
+		   guint32 * nb_cat, guint32 * nb_disks, guint32 * nb_dirs,
 		   guint32 * nb_dirs_with_vfs, guint32 * nb_files,
 		   guint32 * nb_files_with_vfs, guint32 * total_size,
 		   guint32 * total_size_2, guint32 * nb_vfs)
